@@ -43,6 +43,7 @@ describe("add", function () {
       var expected =
         "'assert' option must be a Function, taking at least one argument";
       var options = {
+        // eslint-disable-next-line no-empty-function
         assert: function () {},
       };
       var error;
@@ -66,6 +67,7 @@ describe("add", function () {
         assert: function (actual) {
           return actual;
         },
+        // eslint-disable-next-line no-empty-function
         refute: function () {},
       };
       var error;
@@ -83,7 +85,8 @@ describe("add", function () {
 
   context("when called with invalid assertMessage option", function () {
     it("should throw a TypeError", function () {
-      var expected = "'assertMessage' option must be a non-empty String";
+      var expected =
+        "'assertMessage' option must be a non-empty String or Function";
       var options = {
         assert: function (actual) {
           return actual;
@@ -108,7 +111,8 @@ describe("add", function () {
 
   context("when called with invalid refuteMessage option", function () {
     it("should throw a TypeError", function () {
-      var expected = "'refuteMessage' option must be a non-empty String";
+      var expected =
+        "'refuteMessage' option must be a non-empty String or Function";
       var options = {
         assert: function (actual) {
           return actual;
