@@ -1,7 +1,5 @@
 "use strict";
 
-var includes = require("lodash.includes");
-
 var noClassNameMessage =
   "${customMessage}Expected object to have className property";
 
@@ -16,7 +14,7 @@ module.exports = function (referee) {
       var actual = element.className.split(" ");
       var i, l;
       for (i = 0, l = expected.length; i < l; i++) {
-        if (!includes(actual, expected[i])) {
+        if (!actual.includes(expected[i])) {
           return false;
         }
       }
