@@ -225,9 +225,7 @@ describe("refute.className", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.className] " +
-            message +
-            ": Expected object's className not to include 'item'"
+          `[refute.className] ${message}: Expected object's className not to include 'item'`
         );
         assert.equal(error.name, "AssertionError");
         return true;
