@@ -37,7 +37,7 @@ describe("assert.contains", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.contains] " + message + ": Expected [ 0, 1, 2 ] to contain 3"
+          `[assert.contains] ${message}: Expected [ 0, 1, 2 ] to contain 3`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.contains");
@@ -104,9 +104,7 @@ describe("refute.contains", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.contains] " +
-            message +
-            ": Expected [ 0, 1, 2 ] not to contain 1"
+          `[refute.contains] ${message}: Expected [ 0, 1, 2 ] not to contain 1`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.contains");
