@@ -4,9 +4,11 @@ var assert = require("assert");
 var inspect = require("util").inspect;
 var referee = require("../referee");
 
+// eslint-disable-next-line no-empty-function
 function MyThing() {}
 var myThing = new MyThing();
 var otherThing = {};
+// eslint-disable-next-line no-empty-function
 function F() {}
 F.prototype = myThing;
 var specializedThing = new F();
@@ -23,9 +25,7 @@ describe("assert.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.hasPrototype] Expected {} to have " +
-            myThingString +
-            " on its prototype chain"
+          `[assert.hasPrototype] Expected {} to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.hasPrototype");
@@ -43,9 +43,7 @@ describe("assert.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.hasPrototype] Expected 3 to have " +
-            myThingString +
-            " on its prototype chain"
+          `[assert.hasPrototype] Expected 3 to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.hasPrototype");
@@ -107,11 +105,7 @@ describe("assert.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.hasPrototype] " +
-            message +
-            ": Expected {} to have " +
-            myThingString +
-            " on its prototype chain"
+          `[assert.hasPrototype] ${message}: Expected {} to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.hasPrototype");
@@ -165,9 +159,7 @@ describe("refute.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.hasPrototype] Expected MyThing {} not to have " +
-            myThingString +
-            " on its prototype chain"
+          `[refute.hasPrototype] Expected MyThing {} not to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.hasPrototype");
@@ -185,9 +177,7 @@ describe("refute.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.hasPrototype] Expected MyThing {} not to have " +
-            myThingString +
-            " on its prototype chain"
+          `[refute.hasPrototype] Expected MyThing {} not to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.hasPrototype");
@@ -219,11 +209,7 @@ describe("refute.hasPrototype", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.hasPrototype] " +
-            message +
-            ": Expected MyThing {} not to have " +
-            myThingString +
-            " on its prototype chain"
+          `[refute.hasPrototype] ${message}: Expected MyThing {} not to have ${myThingString} on its prototype chain`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.hasPrototype");
