@@ -79,7 +79,7 @@ describe("assert.isArray", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isArray] " + message + ": Expected {} to be array"
+          `[assert.isArray] ${message}: Expected {} to be array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isArray");
@@ -130,7 +130,7 @@ describe("refute.isArray", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isArray] " + message + ": Expected [] not to be array"
+          `[refute.isArray] ${message}: Expected [] not to be array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isArray");
