@@ -60,9 +60,7 @@ describe("assert.isBoolean", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isBoolean] " +
-            message +
-            ": Expected 'hello' ('string') to be boolean"
+          `[assert.isBoolean] ${message}: Expected 'hello' ('string') to be boolean`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isBoolean");
@@ -109,7 +107,7 @@ describe("refute.isBoolean", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isBoolean] " + message + ": Expected true not to be boolean"
+          `[refute.isBoolean] ${message}: Expected true not to be boolean`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isBoolean");
