@@ -100,7 +100,7 @@ describe("assert.isDataView", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isDataView] " + message + ": Expected [] to be a DataView"
+          `[assert.isDataView] ${message}: Expected [] to be a DataView`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isDataView");
@@ -162,16 +162,14 @@ describe("refute.isDataView", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isDataView] " +
-            message +
-            ": Expected DataView {\n" +
-            "  byteLength: 8,\n" +
-            "  byteOffset: 0,\n" +
-            "  buffer: ArrayBuffer {\n" +
-            "    [Uint8Contents]: <00 00 00 00 00 00 00 00>,\n" +
-            "    byteLength: 8\n" +
-            "  }\n" +
-            "} not to be a DataView"
+          `[refute.isDataView] ${message}: Expected DataView {\n` +
+            `  byteLength: 8,\n` +
+            `  byteOffset: 0,\n` +
+            `  buffer: ArrayBuffer {\n` +
+            `    [Uint8Contents]: <00 00 00 00 00 00 00 00>,\n` +
+            `    byteLength: 8\n` +
+            `  }\n` +
+            `} not to be a DataView`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isDataView");
