@@ -104,7 +104,7 @@ describe("assert.isDate", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isDate] " + message + ": Expected {} to be a Date"
+          `[assert.isDate] ${message}: Expected {} to be a Date`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isDate");
@@ -161,13 +161,10 @@ describe("refute.isDate", function () {
     // In node 6+8 date.toString() uses "(UTC)" as suffix in UTC timezone
     // In node 10 date.toString() uses "(Coordinated Universal Time)"
     var suffix = date.toString().match(/\(.*\)$/)[0];
-    var expectedMessage =
-      "[refute.isDate] " +
-      message +
-      ": Expected 1899-12-31T00:00:00.000Z not to be a Date".replace(
-        "{suffix}",
-        suffix
-      );
+    var expectedMessage = `[refute.isDate] ${message}${": Expected 1899-12-31T00:00:00.000Z not to be a Date".replace(
+      "{suffix}",
+      suffix
+    )}`;
 
     assert.throws(
       function () {
