@@ -115,9 +115,7 @@ describe("assert.isError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isError] " +
-            message +
-            ": Expected 'not an error instance' to be an Error"
+          `[assert.isError] ${message}: Expected 'not an error instance' to be an Error`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isError");
@@ -281,7 +279,7 @@ describe("refute.isError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isError] " + message + ": Expected Error not to be an Error"
+          `[refute.isError] ${message}: Expected Error not to be an Error`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isError");
