@@ -200,9 +200,7 @@ describe("assert.isEvalError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isEvalError] " +
-            message +
-            ": Expected Error to be an EvalError"
+          `[assert.isEvalError] ${message}: Expected Error to be an EvalError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isEvalError");
@@ -282,9 +280,7 @@ describe("refute.isEvalError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isEvalError] " +
-            message +
-            ": Expected EvalError not to be an EvalError"
+          `[refute.isEvalError] ${message}: Expected EvalError not to be an EvalError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isEvalError");
