@@ -121,7 +121,7 @@ describe("assert.isFalse", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isFalse] " + message + ": Expected true to be false"
+          `[assert.isFalse] ${message}: Expected true to be false`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isFalse");
@@ -185,7 +185,7 @@ describe("refute.isFalse", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isFalse] " + message + ": Expected false to not be false"
+          `[refute.isFalse] ${message}: Expected false to not be false`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isFalse");
