@@ -1,6 +1,7 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
@@ -10,15 +11,19 @@ describe("assert.isFloat32Array", function () {
   });
 
   it("should fail for Float64Array", function () {
+    const actual = new Float64Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isFloat32Array(new Float64Array(2));
+        referee.assert.isFloat32Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isFloat32Array] Expected Float64Array(2) [ 0, 0 ] to be a Float32Array"
+          `[assert.isFloat32Array] Expected ${inspect(
+            actual
+          )} to be a Float32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isFloat32Array");
@@ -83,18 +88,19 @@ describe("assert.isFloat32Array", function () {
 
   it("should fail with custom message", function () {
     var message = "b547be3f-9453-4034-a3ee-e6dfe0f26fa1";
+    const actual = new Float64Array(2);
 
     assert.throws(
       function () {
-        referee.assert.isFloat32Array(new Float64Array(2), message);
+        referee.assert.isFloat32Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isFloat32Array] " +
-            message +
-            ": Expected Float64Array(2) [ 0, 0 ] to be a Float32Array"
+          `[assert.isFloat32Array] ${message}: Expected ${inspect(
+            actual
+          )} to be a Float32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isFloat32Array");
@@ -106,15 +112,19 @@ describe("assert.isFloat32Array", function () {
 
 describe("refute.isFloat32Array", function () {
   it("should fail for Float32Array", function () {
+    const actual = new Float32Array(2);
+
     assert.throws(
       function () {
-        referee.refute.isFloat32Array(new Float32Array(2));
+        referee.refute.isFloat32Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isFloat32Array] Expected Float32Array(2) [ 0, 0 ] not to be a Float32Array"
+          `[refute.isFloat32Array] Expected ${inspect(
+            actual
+          )} not to be a Float32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isFloat32Array");
@@ -141,18 +151,19 @@ describe("refute.isFloat32Array", function () {
 
   it("should fail with custom message", function () {
     var message = "2cc86fd1-dd39-44ed-a7c6-e5b83a16e27e";
+    const actual = new Float32Array(2);
 
     assert.throws(
       function () {
-        referee.refute.isFloat32Array(new Float32Array(2), message);
+        referee.refute.isFloat32Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isFloat32Array] " +
-            message +
-            ": Expected Float32Array(2) [ 0, 0 ] not to be a Float32Array"
+          `[refute.isFloat32Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be a Float32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isFloat32Array");
