@@ -1,20 +1,25 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
 describe("assert.isInt16Array", function () {
   it("should fail for Int8Array", function () {
+    const actual = new Int8Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt16Array(new Int8Array(2));
+        referee.assert.isInt16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt16Array] Expected Int8Array(2) [ 0, 0 ] to be an Int16Array"
+          `[assert.isInt16Array] Expected ${inspect(
+            actual
+          )} to be an Int16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt16Array");
@@ -28,15 +33,19 @@ describe("assert.isInt16Array", function () {
   });
 
   it("should fail for Int32Array", function () {
+    const actual = new Int32Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt16Array(new Int32Array(2));
+        referee.assert.isInt16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt16Array] Expected Int32Array(2) [ 0, 0 ] to be an Int16Array"
+          `[assert.isInt16Array] Expected ${inspect(
+            actual
+          )} to be an Int16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt16Array");
@@ -110,9 +119,7 @@ describe("assert.isInt16Array", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt16Array] " +
-            message +
-            ": Expected [Arguments] {} to be an Int16Array"
+          `[assert.isInt16Array] ${message}: Expected [Arguments] {} to be an Int16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt16Array");
@@ -128,15 +135,19 @@ describe("refute.isInt16Array", function () {
   });
 
   it("should fail for Int16Array", function () {
+    const actual = new Int16Array(2);
+
     assert.throws(
       function () {
-        referee.refute.isInt16Array(new Int16Array(2));
+        referee.refute.isInt16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt16Array] Expected Int16Array(2) [ 0, 0 ] not to be an Int16Array"
+          `[refute.isInt16Array] Expected ${inspect(
+            actual
+          )} not to be an Int16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt16Array");
@@ -163,18 +174,19 @@ describe("refute.isInt16Array", function () {
 
   it("should fail with custom message", function () {
     var message = "1cf37727-f020-4ce8-840d-acb7ffc2ac21";
+    const actual = new Int16Array(2);
 
     assert.throws(
       function () {
-        referee.refute.isInt16Array(new Int16Array(2), message);
+        referee.refute.isInt16Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt16Array] " +
-            message +
-            ": Expected Int16Array(2) [ 0, 0 ] not to be an Int16Array"
+          `[refute.isInt16Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be an Int16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt16Array");
