@@ -1,20 +1,25 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
 describe("assert.isInt32Array", function () {
   it("should fail for Int8Array", function () {
+    const actual = new Int8Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt32Array(new Int8Array(2));
+        referee.assert.isInt32Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt32Array] Expected Int8Array(2) [ 0, 0 ] to be an Int32Array"
+          `[assert.isInt32Array] Expected ${inspect(
+            actual
+          )} to be an Int32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt32Array");
@@ -24,15 +29,19 @@ describe("assert.isInt32Array", function () {
   });
 
   it("should fail for Int16Array", function () {
+    const actual = new Int16Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt32Array(new Int16Array(2));
+        referee.assert.isInt32Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt32Array] Expected Int16Array(2) [ 0, 0 ] to be an Int32Array"
+          `[assert.isInt32Array] Expected ${inspect(
+            actual
+          )} to be an Int32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt32Array");
@@ -110,9 +119,7 @@ describe("assert.isInt32Array", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt32Array] " +
-            message +
-            ": Expected [Arguments] {} to be an Int32Array"
+          `[assert.isInt32Array] ${message}: Expected [Arguments] {} to be an Int32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt32Array");
@@ -132,15 +139,19 @@ describe("refute.isInt32Array", function () {
   });
 
   it("should fail for Int32Array", function () {
+    const actual = new Int32Array(2);
+
     assert.throws(
       function () {
-        referee.refute.isInt32Array(new Int32Array(2));
+        referee.refute.isInt32Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt32Array] Expected Int32Array(2) [ 0, 0 ] not to be an Int32Array"
+          `[refute.isInt32Array] Expected ${inspect(
+            actual
+          )} not to be an Int32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt32Array");
@@ -163,18 +174,19 @@ describe("refute.isInt32Array", function () {
 
   it("should fail with custom message", function () {
     var message = "82576420-8e5d-4618-b6eb-87bcf00b9170";
+    const actual = new Int32Array(2);
 
     assert.throws(
       function () {
-        referee.refute.isInt32Array(new Int32Array(2), message);
+        referee.refute.isInt32Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt32Array] " +
-            message +
-            ": Expected Int32Array(2) [ 0, 0 ] not to be an Int32Array"
+          `[refute.isInt32Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be an Int32Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt32Array");
