@@ -3,6 +3,7 @@
 var assert = require("assert");
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
+var inspect = require("util").inspect;
 
 describe("assert.isIntlNumberFormat", function () {
   it("should pass for Intl.NumberFormat", function () {
@@ -92,9 +93,7 @@ describe("assert.isIntlNumberFormat", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isIntlNumberFormat] " +
-            message +
-            ": Expected 'apple pie' to be an Intl.NumberFormat"
+          `[assert.isIntlNumberFormat] ${message}: Expected 'apple pie' to be an Intl.NumberFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isIntlNumberFormat");
@@ -106,15 +105,18 @@ describe("assert.isIntlNumberFormat", function () {
 
 describe("refute.isIntlNumberFormat", function () {
   it("should fail for Intl.NumberFormat", function () {
+    const object = new Intl.NumberFormat();
     assert.throws(
       function () {
-        referee.refute.isIntlNumberFormat(new Intl.NumberFormat());
+        referee.refute.isIntlNumberFormat(object);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isIntlNumberFormat] Expected NumberFormat [Object] {} not to be an Intl.NumberFormat"
+          `[refute.isIntlNumberFormat] Expected ${inspect(
+            object
+          )} not to be an Intl.NumberFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isIntlNumberFormat");
@@ -141,17 +143,18 @@ describe("refute.isIntlNumberFormat", function () {
 
   it("should fail with custom message", function () {
     var message = "f84e51dd-d5af-4ef0-81ec-2d575eadd735";
+    var object = new Intl.NumberFormat();
     assert.throws(
       function () {
-        referee.refute.isIntlNumberFormat(new Intl.NumberFormat(), message);
+        referee.refute.isIntlNumberFormat(object, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isIntlNumberFormat] " +
-            message +
-            ": Expected NumberFormat [Object] {} not to be an Intl.NumberFormat"
+          `[refute.isIntlNumberFormat] ${message}: Expected ${inspect(
+            object
+          )} not to be an Intl.NumberFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isIntlNumberFormat");
