@@ -4,6 +4,7 @@ var assert = require("assert");
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
+// eslint-disable-next-line no-empty-function
 function noop() {}
 
 describe("assert.isNaN", function () {
@@ -205,7 +206,7 @@ describe("assert.isNaN", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isNaN] " + message + ": Expected null to be NaN"
+          `[assert.isNaN] ${message}: Expected null to be NaN`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isNaN");
@@ -286,7 +287,7 @@ describe("refute.isNaN", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isNaN] " + message + ": Expected not to be NaN"
+          `[refute.isNaN] ${message}: Expected not to be NaN`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isNaN");
