@@ -4,6 +4,7 @@ var assert = require("assert");
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
+// eslint-disable-next-line no-empty-function
 function noop() {}
 
 describe("assert.isPromise", function () {
@@ -111,9 +112,7 @@ describe("assert.isPromise", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isPromise] " +
-            message +
-            ": Expected 'apple pie' to be a Promise"
+          `[assert.isPromise] ${message}: Expected 'apple pie' to be a Promise`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isPromise");
@@ -173,9 +172,7 @@ describe("refute.isPromise", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isPromise] " +
-            message +
-            ": Expected Promise { 'apple pie' } not to be a Promise"
+          `[refute.isPromise] ${message}: Expected Promise { 'apple pie' } not to be a Promise`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isPromise");
