@@ -200,9 +200,7 @@ describe("assert.isReferenceError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isReferenceError] " +
-            message +
-            ": Expected Error to be a ReferenceError"
+          `[assert.isReferenceError] ${message}: Expected Error to be a ReferenceError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isReferenceError");
@@ -282,9 +280,7 @@ describe("refute.isReferenceError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isReferenceError] " +
-            message +
-            ": Expected ReferenceError not to be a ReferenceError"
+          `[refute.isReferenceError] ${message}: Expected ReferenceError not to be a ReferenceError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isReferenceError");
