@@ -86,7 +86,7 @@ describe("assert.isSet", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isSet] " + message + ": Expected [Arguments] {} to be a Set"
+          `[assert.isSet] ${message}: Expected [Arguments] {} to be a Set`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isSet");
