@@ -200,9 +200,7 @@ describe("assert.isTypeError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isTypeError] " +
-            message +
-            ": Expected Error to be a TypeError"
+          `[assert.isTypeError] ${message}: Expected Error to be a TypeError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isTypeError");
@@ -282,9 +280,7 @@ describe("refute.isTypeError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isTypeError] " +
-            message +
-            ": Expected TypeError not to be a TypeError"
+          `[refute.isTypeError] ${message}: Expected TypeError not to be a TypeError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isTypeError");
