@@ -1,6 +1,7 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var captureArgs = require("../test-helper/capture-args");
 var referee = require("../referee");
 
@@ -10,15 +11,19 @@ describe("assert.isUint16Array", function () {
   });
 
   it("should fail for Uint32Array", function () {
+    const actual = new Uint32Array();
+
     assert.throws(
       function () {
-        referee.assert.isUint16Array(new Uint32Array());
+        referee.assert.isUint16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint16Array] Expected Uint32Array(0) [] to be a Uint16Array"
+          `[assert.isUint16Array] Expected ${inspect(
+            actual
+          )} to be a Uint16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint16Array");
@@ -28,15 +33,19 @@ describe("assert.isUint16Array", function () {
   });
 
   it("should fail for Uint8Array", function () {
+    const actual = new Uint8Array();
+
     assert.throws(
       function () {
-        referee.assert.isUint16Array(new Uint8Array());
+        referee.assert.isUint16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint16Array] Expected Uint8Array(0) [] to be a Uint16Array"
+          `[assert.isUint16Array] Expected ${inspect(
+            actual
+          )} to be a Uint16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint16Array");
@@ -109,9 +118,7 @@ describe("assert.isUint16Array", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint16Array] " +
-            message +
-            ": Expected [] to be a Uint16Array"
+          `[assert.isUint16Array] ${message}: Expected [] to be a Uint16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint16Array");
@@ -123,15 +130,19 @@ describe("assert.isUint16Array", function () {
 
 describe("refute.isUint16Array", function () {
   it("should fail for isUint16Array", function () {
+    const actual = new Uint16Array();
+
     assert.throws(
       function () {
-        referee.refute.isUint16Array(new Uint16Array());
+        referee.refute.isUint16Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isUint16Array] Expected Uint16Array(0) [] not to be a Uint16Array"
+          `[refute.isUint16Array] Expected ${inspect(
+            actual
+          )} not to be a Uint16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isUint16Array");
@@ -142,17 +153,19 @@ describe("refute.isUint16Array", function () {
 
   it("should fail with custom message", function () {
     var message = "7a548ba3-6efc-4300-8af5-7ff42eb9c064";
+    const actual = new Uint16Array();
+
     assert.throws(
       function () {
-        referee.refute.isUint16Array(new Uint16Array(), message);
+        referee.refute.isUint16Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isUint16Array] " +
-            message +
-            ": Expected Uint16Array(0) [] not to be a Uint16Array"
+          `[refute.isUint16Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be a Uint16Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isUint16Array");
