@@ -1,6 +1,7 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var captureArgs = require("../test-helper/capture-args");
 var referee = require("../referee");
 
@@ -10,15 +11,17 @@ describe("assert.isUint8Array", function () {
   });
 
   it("should fail for Uint16Array", function () {
+    const actual = new Uint16Array();
+
     assert.throws(
       function () {
-        referee.assert.isUint8Array(new Uint16Array());
+        referee.assert.isUint8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint8Array] Expected Uint16Array(0) [] to be a Uint8Array"
+          `[assert.isUint8Array] Expected ${inspect(actual)} to be a Uint8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint8Array");
@@ -28,15 +31,17 @@ describe("assert.isUint8Array", function () {
   });
 
   it("should fail for Uint32Array", function () {
+    const actual = new Uint32Array();
+
     assert.throws(
       function () {
-        referee.assert.isUint8Array(new Uint32Array());
+        referee.assert.isUint8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint8Array] Expected Uint32Array(0) [] to be a Uint8Array"
+          `[assert.isUint8Array] Expected ${inspect(actual)} to be a Uint8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint8Array");
@@ -109,9 +114,7 @@ describe("assert.isUint8Array", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isUint8Array] " +
-            message +
-            ": Expected [] to be a Uint8Array"
+          `[assert.isUint8Array] ${message}: Expected [] to be a Uint8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isUint8Array");
@@ -123,15 +126,19 @@ describe("assert.isUint8Array", function () {
 
 describe("refute.isUint8Array", function () {
   it("should fail for isUint8Array", function () {
+    const actual = new Uint8Array();
+
     assert.throws(
       function () {
-        referee.refute.isUint8Array(new Uint8Array());
+        referee.refute.isUint8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isUint8Array] Expected Uint8Array(0) [] not to be a Uint8Array"
+          `[refute.isUint8Array] Expected ${inspect(
+            actual
+          )} not to be a Uint8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isUint8Array");
@@ -142,17 +149,19 @@ describe("refute.isUint8Array", function () {
 
   it("should fail with custom message", function () {
     var message = "9ddf1b4c-4382-4744-ae88-d14c69f20626";
+    const actual = new Uint8Array();
+
     assert.throws(
       function () {
-        referee.refute.isUint8Array(new Uint8Array(), message);
+        referee.refute.isUint8Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isUint8Array] " +
-            message +
-            ": Expected Uint8Array(0) [] not to be a Uint8Array"
+          `[refute.isUint8Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be a Uint8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isUint8Array");
