@@ -1,3 +1,4 @@
+/* eslint-disable prefer-promise-reject-errors -- temporary, long term this should use Error */
 "use strict";
 
 var assert = require("assert");
@@ -24,6 +25,11 @@ describe("resolves factory", function () {
     throw new Error("Unexpected then");
   }
 
+  it("should be a function with arity 1", function () {
+    assert.equal(typeof this.options.assert, "function");
+    assert.equal(this.options.assert.length, 1);
+  });
+
   it("calls referee.add with 'resolves' as name", function () {
     assert(this.fakeReferee.add.calledWith("resolves"));
   });
