@@ -24,7 +24,7 @@ function createVerifier(referee) {
 
       if (expected && count !== expected) {
         throw new Error(
-          "Expected assertion count to be " + expected + " but was " + count
+          `Expected assertion count to be ${expected} but was ${count}`
         );
       }
 
