@@ -35,9 +35,7 @@ describe("match", function () {
           assert.equal(error.code, "ERR_ASSERTION");
           assert.equal(
             error.message,
-            "[assert.equals] { some: 'string', foo: 1, bar: true } expected to be equal to {\n  some: 'string',\n  foo: 1,\n  bar: { test: " +
-              anonymousFunction +
-              ", message: 'typeOf(\"string\")' }\n}"
+            `[assert.equals] { some: 'string', foo: 1, bar: true } expected to be equal to {\n  some: 'string',\n  foo: 1,\n  bar: { test: ${anonymousFunction}, message: 'typeOf("string")' }\n}`
           );
           assert.equal(error.name, "AssertionError");
           assert.equal(error.operator, "assert.equals");
@@ -72,9 +70,7 @@ describe("match", function () {
           assert.equal(error.code, "ERR_ASSERTION");
           assert.equal(
             error.message,
-            "[refute.equals] { some: 'string', foo: 1, bar: 'test' } expected not to be equal to {\n  some: 'string',\n  foo: 1,\n  bar: { test: " +
-              anonymousFunction +
-              ", message: 'typeOf(\"string\")' }\n}"
+            `[refute.equals] { some: 'string', foo: 1, bar: 'test' } expected not to be equal to {\n  some: 'string',\n  foo: 1,\n  bar: { test: ${anonymousFunction}, message: 'typeOf("string")' }\n}`
           );
           assert.equal(error.name, "AssertionError");
           assert.equal(error.operator, "refute.equals");
